// D import file generated from 'derelict/vorbis/file.d'
module derelict.vorbis.file;
private 
{
	import core.stdc.config;
	import std.stdio;
	import derelict.util.loader;
	import derelict.util.system;
	import derelict.ogg.ogg;
	import derelict.vorbis.vorbis;
	static if (Derelict_OS_Windows)
	{
		enum libNames = "vorbisfile.dll, libvorbisfile-3.dll, libvorbisfile.dll";
	}
	else
	{
		static if (Derelict_OS_Mac)
		{
			enum libNames = "libvorbisfile.dylib, libvorbisfile.0.dylib";
		}
		else
		{
			static if (Derelict_OS_Posix)
			{
				enum libNames = "libvorbisfile.so, libvorbisfile.so.3, libvorbisfile.so.3.1.0";
			}
			else
			{
				static assert(0, "Need to implement libvorbisfile libnames for this operating system.");
			}
		}
	}
}
struct ov_callbacks
{
	extern (C) nothrow 
	{
		size_t function(void*, size_t, size_t, void*) read_func;
		int function(void*, ogg_int64_t, int) seek_func;
		int function(void*) close_func;
		c_long function(void*) tell_func;
	}
}
enum 
{
	NOTOPEN = 0,
	PARTOPEN = 1,
	OPENED = 2,
	STREAMSET = 3,
	INITSET = 4,
}
struct OggVorbis_File
{
	void* datasource;
	int seekable;
	ogg_int64_t offset;
	ogg_int64_t end;
	ogg_sync_state oy;
	int links;
	ogg_int64_t* offsets;
	ogg_int64_t* dataoffsets;
	c_long* serialnos;
	ogg_int64_t* pcmlengths;
	vorbis_info* vi;
	vorbis_comment* vc;
	ogg_int64_t pcm_offset;
	int ready_state;
	c_long current_serialno;
	int current_link;
	double bittrack;
	double samptrack;
	ogg_stream_state os;
	vorbis_dsp_state vd;
	vorbis_block vb;
	ov_callbacks callbacks;
}
extern (C) nothrow @nogc 
{
	alias da_ov_clear = int function(OggVorbis_File*);
	alias da_ov_fopen = int function(const(char)*, OggVorbis_File*);
	alias da_ov_open_callbacks = int function(void* datasource, OggVorbis_File*, const(char)*, c_long, ov_callbacks);
	alias da_ov_test_callbacks = int function(void*, OggVorbis_File*, const(char)*, c_long, ov_callbacks);
	alias da_ov_test_open = int function(OggVorbis_File*);
	alias da_ov_bitrate = c_long function(OggVorbis_File*, int);
	alias da_ov_bitrate_instant = c_long function(OggVorbis_File*);
	alias da_ov_streams = c_long function(OggVorbis_File*);
	alias da_ov_seekable = c_long function(OggVorbis_File*);
	alias da_ov_serialnumber = c_long function(OggVorbis_File*, int);
	alias da_ov_raw_total = ogg_int64_t function(OggVorbis_File*, int);
	alias da_ov_pcm_total = ogg_int64_t function(OggVorbis_File*, int);
	alias da_ov_time_total = double function(OggVorbis_File*, int);
	alias da_ov_raw_seek = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_pcm_seek = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_pcm_seek_page = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_time_seek = int function(OggVorbis_File*, double);
	alias da_ov_time_seek_page = int function(OggVorbis_File*, double);
	alias da_ov_raw_seek_lap = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_pcm_seek_lap = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_pcm_seek_page_lap = int function(OggVorbis_File*, ogg_int64_t);
	alias da_ov_time_seek_lap = int function(OggVorbis_File*, double);
	alias da_ov_time_seek_page_lap = int function(OggVorbis_File*, double);
	alias da_ov_raw_tell = ogg_int64_t function(OggVorbis_File*);
	alias da_ov_pcm_tell = ogg_int64_t function(OggVorbis_File*);
	alias da_ov_time_tell = double function(OggVorbis_File*);
	alias da_ov_info = vorbis_info* function(OggVorbis_File*, int);
	alias da_ov_comment = vorbis_comment* function(OggVorbis_File*, int);
	alias da_ov_read_float = c_long function(OggVorbis_File*, float***, int, int*);
	alias da_ov_read_filter = c_long function(OggVorbis_File*, char*, int, int, int, int, int*);
	alias da_ov_read = c_long function(OggVorbis_File*, byte*, int, int, int, int, int*);
	alias da_ov_crosslap = int function(OggVorbis_File*, OggVorbis_File*);
	alias da_ov_halfrate = int function(OggVorbis_File*, int);
	alias da_ov_halfrate_p = int function(OggVorbis_File*);
}
private extern (C) nothrow 
{
	size_t Derelict_VorbisRead(void* ptr, size_t byteSize, size_t sizeToRead, void* datasource);
	int Derelict_VorbisSeek(void* datasource, ogg_int64_t offset, int whence);
	int Derelict_VorbisClose(void* datasource);
	c_long Derelict_VorbisTell(void* datasource);
}
int ov_open(FILE* f, OggVorbis_File* vf, const(char)* initial, c_long ibytes);
int ov_test(FILE* f, OggVorbis_File* vf, const(char)* initial, c_long ibytes);
__gshared 
{
	da_ov_clear ov_clear;
	da_ov_fopen ov_fopen;
	da_ov_open_callbacks ov_open_callbacks;
	da_ov_test_callbacks ov_test_callbacks;
	da_ov_test_open ov_test_open;
	da_ov_bitrate ov_bitrate;
	da_ov_bitrate_instant ov_bitrate_instant;
	da_ov_streams ov_streams;
	da_ov_seekable ov_seekable;
	da_ov_serialnumber ov_serialnumber;
	da_ov_raw_total ov_raw_total;
	da_ov_pcm_total ov_pcm_total;
	da_ov_time_total ov_time_total;
	da_ov_raw_seek ov_raw_seek;
	da_ov_pcm_seek ov_pcm_seek;
	da_ov_pcm_seek_page ov_pcm_seek_page;
	da_ov_time_seek ov_time_seek;
	da_ov_time_seek_page ov_time_seek_page;
	da_ov_raw_seek_lap ov_raw_seek_lap;
	da_ov_pcm_seek_lap ov_pcm_seek_lap;
	da_ov_pcm_seek_page_lap ov_pcm_seek_page_lap;
	da_ov_time_seek_lap ov_time_seek_lap;
	da_ov_time_seek_page_lap ov_time_seek_page_lap;
	da_ov_raw_tell ov_raw_tell;
	da_ov_pcm_tell ov_pcm_tell;
	da_ov_time_tell ov_time_tell;
	da_ov_info ov_info;
	da_ov_comment ov_comment;
	da_ov_read_float ov_read_float;
	da_ov_read_filter ov_read_filter;
	da_ov_read ov_read;
	da_ov_crosslap ov_crosslap;
	da_ov_halfrate ov_halfrate;
	da_ov_halfrate_p ov_halfrate_p;
}
class DerelictVorbisFileLoader : SharedLibLoader
{
	public this()
	{
		super(libNames);
	}
	protected override void loadSymbols();
}
__gshared DerelictVorbisFileLoader DerelictVorbisFile;
shared static this();
